# CPU type
set cpu_type TMS320C2800

# Flash support
set flash_types { 0 1 2 3 }

# target-side code of flash loader
set FlashLoadSuppCode $mypath/trgcode/flash28335.out

# target is little endian
set TargetBigEndian 0

# PC register name
set pc_name PC
##############################################################
# base address of I2C controller
set i2c0_base 0x7900
##############################################################
# base address of SPI0 controller
set spi0_base 0x7040
##############################################################
# base address of MCBSP0 controller
set mcbsp0_base 0x5000
##############################################################
# base address of MCBSP1 controller
set mcbsp1_base 0x5040

# Word width (0 - 8 bit, 1 - 16, 2 - 32)
set word_width 1

##############################################################
# start address of flash itself in CPU's address space
#
set internal_flash_base 0x300000

# parameters of Internal Flash
# TMS320C28335 contains 8 sectors, 64 Kbyte size each (32Kx16)

set internal_flash_sectors  {
  { 65536 7 }
  { 65536 6 }
  { 65536 5 }
  { 65536 4 } 
  { 65536 3 }
  { 65536 2 }
  { 65536 1 }
  { 65536 0 } }

# Max core frequency in Hz
set cpu_fmax 150000000

##############################################################
#Calculate max posible frequency of CPU
##############################################################
set i 10
set brd_fmax [expr $quarz_frequency*$i/2]

while {$brd_fmax>$cpu_fmax} {
    set brd_fmax [expr $quarz_frequency*$i/2]	
    set i [expr $i - 1]
}

# Set time of command cycle in nS
set cycle_time [expr 1000000000 / $brd_fmax]

# Set flash scale factor
set flash_scale [expr 1048576*200/$cycle_time]


###########################################################################
# CPU clock frequency
###########################################################################
set cpu_clock $brd_fmax
set periph_clock $brd_fmax


###########################################################################
# CPU-specific initialization
###########################################################################
proc CPUSpecificInit { dev } {
                  
  upvar 1 flash_type flash_type
  upvar 1 csm_password csm_password 
  upvar 1 iftype iftype
  upvar 1 brd_fmax brd_fmax  
  upvar 1 quarz_frequency quarz_frequency

  # OBJMODE=1
  # AMODE=0
  WriteReg $dev ST1 [expr ([ReadReg $dev ST1] & 0xFEFF) | 0x200]

  puts "Unlocking CSM"

  # Unlock CSM
  #
  ReadShort $dev 0x33FFF8 1
  ReadShort $dev 0x33FFF9 1
  ReadShort $dev 0x33FFFA 1
  ReadShort $dev 0x33FFFB 1
  ReadShort $dev 0x33FFFC 1
  ReadShort $dev 0x33FFFD 1
  ReadShort $dev 0x33FFFE 1
  ReadShort $dev 0x33FFFF 1

  PutShort $dev 0xAE0 1 [lindex $csm_password 0]
  PutShort $dev 0xAE1 1 [lindex $csm_password 1]
  PutShort $dev 0xAE2 1 [lindex $csm_password 2]
  PutShort $dev 0xAE3 1 [lindex $csm_password 3]
  PutShort $dev 0xAE4 1 [lindex $csm_password 4]
  PutShort $dev 0xAE5 1 [lindex $csm_password 5]
  PutShort $dev 0xAE6 1 [lindex $csm_password 6]
  PutShort $dev 0xAE7 1 [lindex $csm_password 7]

  puts "Stop the WD Timer"
  PutShort $dev 0x7029 1 0x00E8
  puts [format "WDCR=0x%04x" [ReadShort $dev 0x7029 1]]

  # Set PLL parameters

  set PLLSTS [ReadShort $dev 0x7011 1]
  set PLLCR [expr 2*$brd_fmax/$quarz_frequency]
  if { ($PLLSTS & 0x08) != 8} {
     PutShort $dev 0x7011 1 [expr $PLLSTS | 0x40]
     PutShort $dev 0x7021 1 $PLLCR
     PutShort $dev 0x7029 1 0x0068
     PutShort $dev 0x7011 1 [expr [ReadShort $dev 0x7011 1] & 0xFFBF]
  } else {
    xerror $dev "CPU's PLL is in limp mode (no input clock), can't continue" 1
  }
  puts [format "PLLCR=0x%04x" [ReadShort $dev 0x7021 1]]

  puts "Peripheral clock= SYSCLKOUT/1 "
  PutShort $dev 0x701A 1 0x0
  puts [format "HISPCP=0x%04x" [ReadShort $dev 0x701A 1]] 
  PutShort $dev 0x701B 1 0x0
  puts [format "LOSPCP=0x%04x" [ReadShort $dev 0x701B 1]] 

  if { $flash_type == 0 } {

    # Enable I2C pins

    puts "Configuring mux to enable I2C pins"
    # GPAPUD
    PutShort $dev 0x6F9C 1 0x0000
    # GPBQSEL1
    PutShort $dev 0x6F92 1 0x000F
    # GPBMUX1
    PutShort $dev 0x6F96 1 0x0005

    # Enable I2C clock

    puts "Enabling I2C module clock"
    # PCLKCR0
    PutShort $dev 0x701C 1 0x0010

  }
  if { $flash_type == 2  && $iftype == 3 } {

        # Enable SPI pins
        # GPBPUD for All pins
        PutShort $dev 0x6F9C 1 0x0000
        PutShort $dev 0x6F9D 1 0x0000
      
	#GPBQSEL2
        PutShort $dev 0x6F94 1 0xF000        
        PutShort $dev 0x6F95 1 0x0003        
	#GPBMUX2
        PutShort $dev 0x6F98 1 0x5000        
        PutShort $dev 0x6F99 1 0x0001        

    	PutShort $dev 0x701C 1 0x03C0
   }

  if { $flash_type == 2  && $iftype == 2 } {
        # Enable MCBSP pins

   }

}




